@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+from __future__ import unicode_literals, division, print_function, absolute_import
 
 class Error(Exception):
     """all prom errors will inherit from this base class"""
@@ -10,3 +12,7 @@ class Error(Exception):
 class InterfaceError(Error):
     """specifically for wrapping SQLite and Postgres errors"""
     pass
+
+
+class UniqueError(InterfaceError):
+    pass
